import React, { useState, useEffect, useRef } from 'react';
import { Button, Modal,message } from 'antd';
import request, { apis } from '@/utils/request';
import Form from './Form';
import List from './List';

export default props => {
  const [visible, setVisible] = useState(false);
  const { history } = props;
  const { query } = history.location;
  const { id } = query;

  const [loading, setLoading] = useState(false);
  const [list, setList] = useState([]);
  const albumRef = useRef();

  const getList = () => {
    // const urlData = { id };
    // const params = { apartmentType: 'apart' };

    setLoading(true);

    request({
      ...apis.building.buildingApartment,
      urlData: { id },
      params: { apartmentType: 'photo' },
    })
      .then(res => {
        setList(res);
        setLoading(false);
      })
      .catch(err => {
        console.error(err.message || err);
        setLoading(false);
      });
  };

  const handleEdit = record => {
    albumRef.current = record;
    setVisible(true);
  };

  function handleDelete(record) {
    Modal.confirm({
      title: '确认删除当前相册',
      // content: 'Bla bla ...',
      okText: '确认',
      cancelText: '取消',
      onOk: () => {
        request({ ...apis.building.buildingApartmentDelete, urlData: { id: record.apartmentId } })
          .then(() => {
            console.log('删除成功')
            message.success('删除成功');
            getList();
          })
          .catch(err => {
            console.log('删除失败')
          });
      },
    });
  }

  // const handleDelete = record => {
  //   const urlData = { id: record.apartmentId };

  //   setLoading(true);
  //   deleteData({ urlData })
  //     .then(() => {
  //       getList();
  //       message.success('删除成功');
  //       setLoading(false);
  //     })
  //     .catch(err => {
  //       console.error(err.message || err);
  //       setLoading(false);
  //     });
  // };

  const handleSuccess = () => {
    getList();
    setVisible(false);
  };

  const onRename = () => {
    getList();
    setVisible(false);
  };

  useEffect(() => {
    getList();
  }, [id]);
  return (
    <div>
      <div>
        <Button type="primary" onClick={() => setVisible(true)}>
          新增相册
        </Button>
      </div>
      <Form
        visible={visible}
        buildingId={id}
        onCancel={() => setVisible(false)}
        onSuccess={() => handleSuccess()}
      />
      <List
        loading={loading}
        dataList={list}
        onEdit={handleEdit}
        onRename={onRename}
        onDelete={handleDelete}
      />
    </div>
  );
};
